@@ -4,7 +4,7 @@ from abc import ABC, abstractmethod
 import pygame
 
 from .colors import WHITE, BLACK, MEDIUM_GRAY
-from multitouch.raspberrypi_ts import TS_PRESS, TS_RELEASE, TS_MOVE
+from .multitouch.raspberrypi_ts import TS_PRESS, TS_RELEASE, TS_MOVE
 
 FONT_NAME = None
 
